@@ -67,8 +67,7 @@ class Korodata():
         plt.title(herriname, fontsize=26, pad=50)
         plt.xticks(rotation=45, ha="right")
         plt.tight_layout()
-        plt.savefig('./korodata/grafikak/' +
-                    "".join(x for x in herriname if x.isalnum()) + '.png')
+        plt.savefig("".join(x for x in herriname if x.isalnum()) + '.png')
         plt.close(plt.figure(j, figsize=(14, 9)))
 
     def set_color(i, color, colors_l, barlist):
@@ -442,7 +441,7 @@ class Korodata():
             plt.title(
                 "100.000 biztanleko positibo kopurua azken 7 egunak batuta", fontsize=26, pad=50)
             plt.tight_layout()
-            plt.savefig('./korodata/grafikak/100.png')
+            plt.savefig('100.png')
             plt.close(plt.figure(0, figsize=(14, 8)))
 
     def gorriak():
